@@ -1,4 +1,4 @@
-// Copyright 2020-2021 The NATS Authors
+// Copyright 2020-2022 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -15,19 +15,23 @@ use std::cmp;
 use std::convert::TryInto;
 use std::fmt;
 use std::io;
+use std::io::Error;
 use std::path::{Path, PathBuf};
 use std::sync::Arc;
 use std::time::Duration;
 
 use crate::auth_utils;
 use crate::secure_wipe::SecureString;
+use crate::Client;
 use crate::Connection;
+use crate::IntoServerList;
 
 /// Connect options.
 pub struct Options {
     pub(crate) auth: AuthStyle,
     pub(crate) name: Option<String>,
     pub(crate) no_echo: bool,
+    pub(crate) retry_on_failed_connect: bool,
     pub(crate) max_reconnects: Option<usize>,
     pub(crate) reconnect_buffer_size: usize,
     pub(crate) tls_required: bool,
@@ -36,11 +40,12 @@ pub struct Options {
     pub(crate) client_key: Option<PathBuf>,
     pub(crate) tls_client_config: crate::rustls::ClientConfig,
 
+    pub(crate) error_callback: ErrorCallback,
     pub(crate) disconnect_callback: Callback,
     pub(crate) reconnect_callback: Callback,
     pub(crate) reconnect_delay_callback: ReconnectDelayCallback,
     pub(crate) close_callback: Callback,
-    pub(crate) jetstream_prefix: String,
+    pub(crate) lame_duck_callback: Callback,
 }
 
 impl fmt::Debug for Options {
@@ -49,6 +54,7 @@ impl fmt::Debug for Options {
             .entry(&"auth", &self.auth)
             .entry(&"name", &self.name)
             .entry(&"no_echo", &self.no_echo)
+            .entry(&"retry_on_failed_connect", &self.retry_on_failed_connect)
             .entry(&"reconnect_buffer_size", &self.reconnect_buffer_size)
             .entry(&"max_reconnects", &self.max_reconnects)
             .entry(&"tls_required", &self.tls_required)
@@ -56,10 +62,12 @@ impl fmt::Debug for Options {
             .entry(&"client_cert", &self.client_cert)
             .entry(&"client_key", &self.client_key)
             .entry(&"tls_client_config", &"XXXXXXXX")
+            .entry(&"error_callback", &self.error_callback)
             .entry(&"disconnect_callback", &self.disconnect_callback)
             .entry(&"reconnect_callback", &self.reconnect_callback)
             .entry(&"reconnect_delay_callback", &"set")
             .entry(&"close_callback", &self.close_callback)
+            .entry(&"lame_duck_callback", &self.lame_duck_callback)
             .finish()
     }
 }
@@ -70,17 +78,19 @@ impl Default for Options {
             auth: AuthStyle::NoAuth,
             name: None,
             no_echo: false,
+            retry_on_failed_connect: false,
             reconnect_buffer_size: 8 * 1024 * 1024,
             max_reconnects: Some(60),
             tls_required: false,
             certificates: Vec::new(),
             client_cert: None,
             client_key: None,
+            error_callback: ErrorCallback(None),
             disconnect_callback: Callback(None),
             reconnect_callback: Callback(None),
             reconnect_delay_callback: ReconnectDelayCallback(Box::new(backoff)),
             close_callback: Callback(None),
-            jetstream_prefix: "$JS.API.".to_string(),
+            lame_duck_callback: Callback(None),
             tls_client_config: crate::rustls::ClientConfig::default(),
         }
     }
@@ -385,6 +395,27 @@ impl Options {
         self
     }
 
+    /// Select option to enable reconnect with backoff
+    /// on first failed connection attempt.
+    /// The reconnect logic with `max_reconnects` and the
+    /// `reconnect_delay_callback` will be specified the same
+    /// as before but will be invoked on the first failed
+    /// connection attempt.
+    ///
+    /// # Example
+    /// ```
+    /// # fn main() -> std::io::Result<()> {
+    /// let nc = nats::Options::new()
+    ///     .retry_on_failed_connect()
+    ///     .connect("demo.nats.io")?;
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn retry_on_failed_connect(mut self) -> Options {
+        self.retry_on_failed_connect = true;
+        self
+    }
+
     /// Set the maximum number of reconnect attempts.
     /// If no servers remain that are under this threshold,
     /// then no further reconnect shall be attempted.
@@ -426,37 +457,54 @@ impl Options {
         self
     }
 
-    /// Establish a `Connection` with a NATS server.
+    /// Establish a `Connection` with one or more NATS servers.
     ///
-    /// Multiple servers may be specified by separating
-    /// them with commas.
+    /// To pass more than one URL check out the the documentation of [`crate::connect()`].
+    ///
+    /// **Note:** If an URL provides username and password, e.g. `nats://derek:s3cr3t!@demo.nats.io`,
+    /// it will override the username and password set by the [`Options`]. Be aware that providing
+    /// credentials in the URL is not safe and should not be used in production.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// let options = nats::Options::new();
+    /// let nc = options.connect("demo.nats.io")?;
+    /// # Ok::<(), std::io::Error>(())
+    /// ```
+    ///
+    /// In the below case, the second server is configured to use TLS but the first one is not.
+    /// Using the [`Options::tls_required()`] method can ensure that all servers are connected
+    /// to with TLS, if that is your intention.
+    ///
+    /// ```
+    /// let options = nats::Options::new();
+    /// let nc = options.connect("nats://demo.nats.io:4222,tls://demo.nats.io:4443")?;
+    /// # Ok::<(), std::io::Error>(())
+    /// ```
+    pub fn connect<I: IntoServerList>(self, nats_urls: I) -> io::Result<Connection> {
+        Connection::connect_with_options(nats_urls, self)
+    }
+
+    /// Set a callback to be executed when an async error from
+    /// a server has been received.
     ///
     /// # Example
     ///
     /// ```
     /// # fn main() -> std::io::Result<()> {
-    /// let options = nats::Options::new();
-    /// let nc = options.connect("demo.nats.io")?;
+    /// let nc = nats::Options::new()
+    ///     .error_callback(|err| println!("connection received an error: {}", err))
+    ///     .connect("demo.nats.io")?;
     /// # Ok(())
     /// # }
     /// ```
-    ///
-    /// In the below case, the second server is configured
-    /// to use TLS but the first one is not. Using the
-    /// `tls_required` method can ensure that all
-    /// servers are connected to with TLS, if that is
-    /// your intention.
-    ///
-    ///
-    /// ```
-    /// # fn main() -> std::io::Result<()> {
-    /// let options = nats::Options::new();
-    /// let nc = options.connect("nats://demo.nats.io:4222,tls://demo.nats.io:4443")?;
-    /// # Ok(())
-    /// # }
-    /// ```
-    pub fn connect(self, nats_url: &str) -> io::Result<Connection> {
-        Connection::connect_with_options(nats_url, self)
+    pub fn error_callback<F>(mut self, cb: F) -> Self
+    where
+        F: Fn(Error) + Send + Sync + 'static,
+    {
+        self.error_callback = ErrorCallback(Some(Box::new(cb)));
+        self
     }
 
     /// Set a callback to be executed when connectivity to
@@ -501,29 +549,6 @@ impl Options {
         self
     }
 
-    /// Set a custom `JetStream` API prefix. This is useful
-    /// when using `JetStream` through exports/imports.
-    ///
-    /// # Example
-    ///
-    /// ```
-    /// # fn main() -> std::io::Result<()> {
-    /// let nc = nats::Options::new()
-    ///     .jetstream_api_prefix("some_exported_prefix".to_string())
-    ///     .connect("demo.nats.io")?;
-    /// nc.drain().unwrap();
-    /// # Ok(())
-    /// # }
-    /// ```
-    pub fn jetstream_api_prefix(mut self, mut jetstream_prefix: String) -> Self {
-        if !jetstream_prefix.ends_with('.') {
-            jetstream_prefix.push('.');
-        }
-
-        self.jetstream_prefix = jetstream_prefix;
-        self
-    }
-
     /// Set a callback to be executed when the client has been
     /// closed due to exhausting reconnect retries to known servers
     /// or by completing a drain request.
@@ -547,6 +572,28 @@ impl Options {
         self
     }
 
+    /// Set a callback to be executed when the server enters lame duck mode.
+    /// Can be set to enable letting user know that client will be soon evicted.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # fn main() -> std::io::Result<()> {
+    /// let nc = nats::Options::new()
+    ///     .lame_duck_callback(|| println!("server entered lame duck mode"))
+    ///     .connect("demo.nats.io")?;
+    /// nc.drain().unwrap();
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn lame_duck_callback<F>(mut self, cb: F) -> Self
+    where
+        F: Fn() + Send + Sync + 'static,
+    {
+        self.lame_duck_callback = Callback(Some(Box::new(cb)));
+        self
+    }
+
     /// Set a callback to be executed for calculating the backoff duration
     /// to wait before a server reconnection attempt.
     ///
@@ -692,3 +739,26 @@ impl ReconnectDelayCallback {
         self.0(reconnects)
     }
 }
+
+pub(crate) struct ErrorCallback(Option<Box<dyn Fn(Error) + Send + Sync + 'static>>);
+impl ErrorCallback {
+    pub fn call(&self, client: &Client, err: Error) {
+        if let Some(callback) = self.0.as_ref() {
+            callback(err);
+        } else {
+            let si = client.server_info();
+            eprintln!("{} on connection [{}]", err, si.client_id);
+        }
+    }
+}
+
+impl fmt::Debug for ErrorCallback {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
+        f.debug_map()
+            .entry(
+                &"error_callback",
+                if self.0.is_some() { &"set" } else { &"unset" },
+            )
+            .finish()
+    }
+}
