@@ -13,12 +13,9 @@
 
 use std::io;
 
-mod util;
-pub use util::*;
-
 #[test]
 fn basic_nkey_auth() -> io::Result<()> {
-    let s = util::run_server("tests/configs/nkey.conf");
+    let s = nats_server::run_server("tests/configs/nkey.conf");
 
     let nkey = "UAMMBNV2EYR65NYZZ7IAK5SIR5ODNTTERJOBOF4KJLMWI45YOXOSWULM";
     let seed = "SUANQDPB2RUOE4ETUA26CNX7FUKE5ZZKFCQIIW63OX225F2CO7UEXTM7ZY";
