@@ -11,12 +11,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-mod util;
-pub use util::*;
-
 #[test]
 fn basic_user_pass_auth() {
-    let s = util::run_server("tests/configs/user_pass.conf");
+    let s = nats_server::run_server("tests/configs/user_pass.conf");
 
     assert!(nats::connect(&s.client_url()).is_err());
 
