@@ -11,13 +11,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-mod util;
-pub use util::*;
+pub use nats_server::*;
 
 #[test]
 #[should_panic(expected = "no responders")]
 fn no_responders() {
-    let s = util::run_basic_server();
+    let s = nats_server::run_basic_server();
     let nc = nats::connect(&s.client_url()).expect("could not connect");
     nc.request("nobody-home", "hello").unwrap();
 }
